ClickhouseConnection

Struct ClickhouseConnection 

pub struct ClickhouseConnection { /* private fields */ }
ClickHouse ADBC Connection implementation.

Sessions in the ClickHouse HTTP Interface

This type does not necessarily represent a persistent TCP connection.

Instead, it makes calls to the ClickHouse HTTP interface. HTTP/1.1 connections are transparently cached in the object.

A random session_id is generated upon construction and subsequently passed to all HTTP interface calls made by this connection and any ClickhouseStatements created from it. Any session-local state (such as settings and temporary tables) is stored in association with this session ID.

The session ID may be overridden or read back using options::SESSION_ID.

Sessions persist for the default session timeout, which is 60 seconds of inactivity. Server-side state is not guaranteed past this timeout.

Tokio Runtime

This connection inherits the Tokio runtime of the parent ClickhouseDriver.

If a runtime was not set when the driver was created, a new current-thread runtime is created for each connection.

See ClickhouseDriver::init() for details.