This type does not necessarily represent a persistent TCP connection.
Instead, it makes calls to the ClickHouse HTTP interface. HTTP/1.1 connections are
transparently cached in the object.
A random session_id is generated upon construction and subsequently passed to all
HTTP interface calls made by this connection and any ClickhouseStatements created from it.
Any session-local state (such as settings and temporary tables) is stored in association
with this session ID.
Casts self to type T. The semantics of numeric casting with the as operator are followed, so <T as As>::as_::<U> can be used in the same way as T as U for numeric conversions. Read more